@@ -102,14 +102,19 @@ class Element(object):
         self.raw_value = Unspecified
 
         if value is Unspecified:
-            if self.default is not Unspecified:
-                value = self.default
-            elif self.default_factory is not Unspecified:
-                value = self.default_factory()
-            self.set_from_native(value)
+            self._set_default_value()
         else:
             self.set_from_raw(value)
 
+    def _set_default_value(self):
+        if self.default is not Unspecified:
+            value = self.default
+        elif self.default_factory is not Unspecified:
+            value = self.default_factory()
+        else:
+            value = Unspecified
+        self.set_from_native(value)
+
     def set_from_native(self, value):
         """
         Sets :attr:`value` to the given `value` and sets attr:`raw_value` to
@@ -118,11 +123,7 @@ class Element(object):
         .. versionadded:: 1.0.0
         """
         self.value = value
-        if value is Unspecified:
-            self.raw_value
-        else:
-            self.value = value
-            self.raw_value = self.serialize(value)
+        self.raw_value = self.serialize(value)
         self.is_valid = None
 
     def set_from_raw(self, raw_value):
@@ -134,10 +135,7 @@ class Element(object):
            Was previously named :meth:`set`.
         """
         self.raw_value = raw_value
-        if raw_value is Unspecified:
-            self.value = raw_value
-        else:
-            self.value = self.unserialize(raw_value)
+        self.value = self.unserialize(raw_value)
         self.is_valid = None
 
     def serialize(self, value):
